import type { Comment, Locations, Token } from "../ast";
import type ESTree from "estree";
import type { ScopeManager } from "eslint-scope";
import { TemplateScopeManager } from "./template-scope-manager";
declare type ContextSourceCode = {
    template: string;
    scripts: {
        code: string;
        attrs: Record<string, string | undefined>;
    };
};
export declare class Context {
    readonly code: string;
    readonly parserOptions: any;
    readonly sourceCode: ContextSourceCode;
    readonly tokens: Token[];
    readonly comments: Comment[];
    private readonly locs;
    private readonly locsMap;
    private _templateScopeManager;
    constructor(code: string, parserOptions: any);
    getLocFromIndex(index: number): {
        line: number;
        column: number;
    };
    /**
     * Get the location information of the given node.
     * @param node The node.
     */
    getConvertLocation(node: {
        start: number;
        end: number;
    } | ESTree.Node): Locations;
    addComment(comment: Comment): void;
    /**
     * Add token to tokens
     */
    addToken(type: Token["type"], range: {
        start: number;
        end: number;
    }): Token;
    /**
     * get text
     */
    getText(range: {
        start: number;
        end: number;
    }): string;
    readyScopeManager(scopeManager: ScopeManager): void;
    get templateScopeManager(): TemplateScopeManager;
}
export declare class LinesAndColumns {
    private readonly lineStartIndices;
    constructor(code: string);
    getLocFromIndex(index: number): {
        line: number;
        column: number;
    };
    getIndexFromLoc(loc: {
        line: number;
        column: number;
    }): number;
}
export {};
